\newcommand\classname{journal}
\newcommand\lastmodifieddate{2002/09/28}
\newcommand\versionnumber{0.1}

% Are we printing crop marks?
\newif\if@cropmarkson \@cropmarksontrue

\NeedsTeXFormat{LaTeX2e}[2001/06/01]
\ProvidesClass{\classname}[\lastmodifieddate\space\versionnumber]

\newif\if@restonecol
\newif\if@titlepage
\newif\if@nameyear

\setlength{\paperheight}{9truein}
\setlength{\paperwidth}{6truein}

\DeclareOption{draft}{\PassOptionsToPackage{draft}{graphicx}}
\DeclareOption{a4paper}{\PassOptionsToPackage{a4}{crop}}
\DeclareOption{a3paper}{\PassOptionsToPackage{a3}{crop}}
\DeclareOption{centre}{\PassOptionsToPackage{center}{crop}}
\DeclareOption{crop}{\PassOptionsToPackage{cam}{crop}\global\@cropmarksontrue}
\DeclareOption{nocrop}{\PassOptionsToPackage{off}{crop}\global\@cropmarksonfalse}
\DeclareOption{info}{\PassOptionsToPackage{info}{crop}}
\DeclareOption{noinfo}{\PassOptionsToPackage{noinfo}{crop}}
\DeclareOption{oneside}{\@twosidefalse \@mparswitchfalse}
\DeclareOption{twoside}{\@twosidetrue  \@mparswitchtrue}
\DeclareOption{titlepage}{\@titlepagetrue}
\DeclareOption{notitlepage}{\@titlepagefalse}
\DeclareOption{onecolumn}{\@twocolumnfalse}
\DeclareOption{twocolumn}{\@twocolumntrue}
\DeclareOption{nameyear}{\@nameyeartrue}


\ExecuteOptions{a4paper,crop,centre,info,twoside}

\ProcessOptions

% Load all necessary packages
\RequirePackage{crop,graphicx,mathtimy,array,fleqn,theorem,latexsym}
\RequirePackage[figuresright]{rotating}


% Not sure if needed.
\newcommand\@ptsize{0}



\renewcommand\normalsize{%
   \@setfontsize\normalsize{10}{12}%
   \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
   \abovedisplayshortskip \z@ \@plus3\p@
   \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
   \belowdisplayskip \abovedisplayskip
   \let\@listi\@listI}
\normalsize
\let\@bls\baselineskip

\newcommand\small{%
    \@setfontsize\small{9}{10}%
    \abovedisplayskip 11\p@ minus 3\p@
    \belowdisplayskip \abovedisplayskip
    \abovedisplayshortskip \z@ plus 2\p@
    \belowdisplayshortskip 4\p@ plus 2\p@ minus2\p@
    \def\@listi{\topsep 4.5\p@ plus 2\p@ minus 1\p@
       \itemsep \parsep
       \topsep 4\p@ plus 2\p@ minus 2\p@}}

\newcommand\footnotesize{%
    \@setfontsize\footnotesize{8}{9}%
    \abovedisplayskip 6\p@ minus 3\p@
    \belowdisplayskip\abovedisplayskip
    \abovedisplayshortskip \z@ plus 3\p@
    \belowdisplayshortskip 6\p@ plus 3\p@ minus 3\p@
    \def\@listi{\topsep 3\p@ plus 1\p@ minus 1\p@
       \parsep 2\p@ plus 1\p@ minus 1\p@\itemsep \parsep}}

\def\scriptsize{\@setfontsize\scriptsize{7pt}{9pt}}
\def\tiny{\@setfontsize\tiny{5pt}{7pt}}
\def\large{\@setfontsize\large{12pt}{14pt}}
\def\Large{\@setfontsize\Large{14pt}{16}}
\def\LARGE{\@setfontsize\LARGE{16pt}{18pt}}
\def\huge{\@setfontsize\huge{24pt}{24pt}}
\def\Huge{\@setfontsize\Huge{30pt}{32pt}}
\newcommand{\runningheadsize}{\@setfontsize\runningheadsize{8\p@}{7.5\p@}}
\newcommand{\authornamesize}{\@setfontsize\authornamesize{16\p@}{16\p@}}

\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}

% Line spacing
\setlength\lineskip{1\p@}
\setlength\normallineskip{1\p@}
\renewcommand\baselinestretch{}

% Paragraph dimensions and inter-para spacing
\setlength\parskip{0\p@}
\setlength\parindent{1pc}

% Set inter-para skips
\setlength\smallskipamount{3\p@ \@plus 1\p@ \@minus 1\p@}
\setlength\medskipamount{6\p@ \@plus 4\p@ \@minus 1\p@}
\setlength\bigskipamount{12\p@ \@plus 4\p@ \@minus 4\p@}

% Page break penalties
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301

% Disallow widows and orphans
\clubpenalty 10000
\widowpenalty 10000

% Disable page breaks before equations, allow pagebreaks after
% equations and discourage widow lines before equations.
\displaywidowpenalty 100
\predisplaypenalty   10000
\postdisplaypenalty  2500

% Allow breaking the page in the middle of a paragraph
\interlinepenalty 0

% Disallow breaking the page after a hyphenated line
\brokenpenalty 10000

% Hyphenation; don't split words into less than three characters
\lefthyphenmin=3
\righthyphenmin=3

%
% Set page layout dimensions
%
\setlength\headheight{7\p@}         % height of running head
\setlength\topmargin{.475in}         % head margin
\addtolength\topmargin{-1in}        % subtract out the 1 inch driver margin

\setlength\topskip{10\p@}           % height of first line of text
\setlength\headsep{24\p@}           % space below running head --
\addtolength\headsep{-\topskip}     %   base to base with first line of text

\setlength\footskip{34\p@}          % space above footer line
\setlength\maxdepth{.5\topskip}     % pages can be short or deep by half a line?

\setlength\textwidth{25.6pc}        % text measure excluding margins

\setlength\textheight{43\baselineskip} % 55 lines on a full page,
\addtolength\textheight{\topskip}      %   including the first
                                       %   line on the page

% Set the margins
\setlength\marginparsep{18\p@}
\setlength\marginparpush{3\p@}
\setlength\marginparwidth{100\p@}

\setlength\oddsidemargin{.875in}
\addtolength\oddsidemargin{-1in}    % subtract out the 1 inch driver margin
\setlength\@tempdima{\paperwidth}
\addtolength\@tempdima{-\textwidth}
\addtolength\@tempdima{-.875in}
\setlength\evensidemargin{\@tempdima}
\addtolength\evensidemargin{-1in}

\setlength\columnsep{1.9pc}            % space between columns for double-column text
\setlength\columnseprule{0\p@}         % width of rule between two columns

% Footnotes
\setlength\footnotesep{\z@}      % space between footnotes
% space between text and footnote
\setlength{\skip\footins}{18\p@ \@plus 6\p@ \@minus 1\p@}


% Float placement parameters

% The total number of floats that can be allowed on a page.
\setcounter{totalnumber}{10}
% The maximum number of floats at the top and bottom of a page.
\setcounter{topnumber}{5}
\setcounter{bottomnumber}{5}
% The maximum part of the top or bottom of a text page that can be
% occupied by floats. This is set so that at least four lines of text
% fit on the page.
\renewcommand\topfraction{.9}
\renewcommand\bottomfraction{.9}
% The minimum amount of a text page that must be occupied by text.
% This should accomodate four lines of text.
\renewcommand\textfraction{.06}
% The minimum amount of a float page that must be occupied by floats.
\renewcommand\floatpagefraction{.94}

% The same parameters repeated for double column output
\renewcommand\dbltopfraction{.9}
\renewcommand\dblfloatpagefraction{.9}

% Space between floats
\setlength\floatsep    {12\p@ \@plus 2\p@ \@minus 2\p@}
% Space between floats and text
\setlength\textfloatsep{20\p@ \@plus 2\p@ \@minus 4\p@}
% Space above and below an inline figure
\setlength\intextsep   {18\p@ \@plus 2\p@ \@minus 2\p@}

% For double column floats
\setlength\dblfloatsep    {12\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\dbltextfloatsep{20\p@ \@plus 2\p@ \@minus 4\p@}

% Space left at top, bottom and inbetween floats on a float page.
\setlength\@fptop{0\p@}         % no space above float page figures
\setlength\@fpsep{12\p@ \@plus 1fil}
\setlength\@fpbot{0\p@}

% The same for double column
\setlength\@dblfptop{0\p@}
\setlength\@dblfpsep{12\p@ \@plus 1fil}
\setlength\@dblfpbot{0\p@}

% Page styles

\def\@journal{Int. Journ. of Unconventional Computing}
\def\@vol{}
\def\@pubyear{}
\def\volume#1{\gdef\@vol{Vol.~#1}}
\def\issue#1{\gdef\@iss{No.~#1}}
\def\pubyear#1{\gdef\@pubyear{#1}}
\def\pagerange#1{\gdef\@pagerange{#1}}
\def\runtitle#1{\gdef\@runtitle{{{{\fontsize{8}{13}\sc\selectfont {#1}}}}}}
\def\runauthor#1{\gdef\@runauthor{{{\fontsize{8}{13}\sc\selectfont {#1}}}}}

\def\ps@openin{\let\@mkboth\@gobble
\def\@oddhead{\fontsize{6}{8}\selectfont\begin{tabular*}{\textwidth}{@{\extracolsep{\fill}}lr@{}}
\noindent{\it \@journal\/},\ {\@vol,}\ pp.\ {\@pagerange}& \copyright\@pubyear\ Old City Publishing, Inc.\\
Reprints available directly from the publisher & Published by license under the OCP Science imprint,\\
Photocopying permitted by license only & a member of the Old City Publishing Group
\end{tabular*}}%%
\def\@evenhead{}%
\def\@oddfoot{\hfill\fontsize{9}{12}\selectfont\thepage\hfill}
\let\@evenfoot\relax}%
%\def\@evenfoot{\thepage\hfill{\sc journal of hydraulic research, vol. 40,\ 2002, no. 2}}}

\def\ps@headings
  {\def\@evenfoot{}
  \def\@oddfoot{}
  \def\@evenhead{{\fontsize{9}{13}\selectfont\thepage}\hfill{{{\fontsize{8}{13}\selectfont\@runauthor}}}\hfill}%
  \def\@oddhead{\hfill{{\fontsize{8}{13}\selectfont\@runtitle}}\hfill\fontsize{9}{13}\sc\selectfont\thepage}%
    \let\@mkboth\@gobbletwo
    \let\sectionmark\@gobble
    \let\subsectionmark\@gobble
  }


\def\ps@plain
  {\reset@font
   \let\@oddhead\relax\let\@evenhead\relax
   \def\@oddfoot{\hfill{\reset@font\normalsize\thepage}}
\def\@evenfoot{\hfill{\reset@font\normalsize\thepage}}   }


% Sectional units
%

% Counters
\newcounter{supersec}
\newcounter{part}[supersec]
\newcounter{chapter}
\newcounter{section}[chapter]
\newcounter{subsection}[section]
\newcounter{subsubsection}[subsection]
\newcounter{paragraph}[subsubsection]
\newcounter{subparagraph}[paragraph]
\newcounter{figure}[chapter]
\newcounter{table}[chapter]
\newcounter{photo}[chapter]
\newbox\t@abstract
\newbox\t@resume

% Form of the numbers
\newcommand\thepage{\arabic{page}}
\renewcommand\thesupersec{\arabic{supersec}}
\renewcommand\thepart{\Alph{part}}
\renewcommand\thechapter{\arabic{chapter}}
\renewcommand\thesection{\arabic{section}}
\renewcommand\thesubsection{{\thesection.\arabic{subsection}}}
\renewcommand\thesubsubsection{{\thesubsection.\arabic{subsubsection}}}
\renewcommand\theparagraph{\thesubsubsection.\arabic{paragraph}}
\renewcommand\thesubparagraph{\theparagraph.\arabic{subparagraph}}
\renewcommand\theequation{\arabic{equation}}
\newcommand\@chapapp{\chaptername}

% Form of the words
\newcommand\contentsname{Contents}
\newcommand\listfigurename{List of Figures}
\newcommand\listtablename{List of Tables}
\newcommand\supersecname{Section}
\newcommand\partname{Part}
\newcommand\chaptername{Chapter}
\newcommand\appendixname{Appendix}
\newcommand\abstractname{ABSTRACT}
\newcommand\resumename{R\'ESUM\'E}
\newcommand\refname{References}
\newcommand\bibname{Bibliography}
\newcommand\indexname{Index}
\newcommand\figurename{FIGURE}
\newcommand\photoname{Photo}
\newcommand\tablename{TABLE}

% Clearemptydoublepage should really clear the running heads too
\newcommand{\clearemptydoublepage}{\newpage{\pagestyle{empty}\cleardoublepage}}

% Frontmatter, mainmatter and backmatter

\newif\if@mainmatter \@mainmattertrue

\newcommand\frontmatter{%
  \clearpage
  \@mainmatterfalse
  \pagenumbering{roman}}

\newcommand\mainmatter{%
  \clearpage
  \@mainmattertrue
  \pagenumbering{arabic}}

\newcommand\backmatter{%
  \clearpage
  \@mainmatterfalse}

% Super section
\def\supersec{\clearpage\thispagestyle{empty}\secdef\@supersec\@ssupersec}



\newcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent \z@\noindent
            \hbox{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \thispagestyle{openin}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\@title\@empty\global\let\title\relax
  \global\let\@subtitle\@empty\global\let\subtitle\relax
  \global\let\@author\@empty\global\let\author\relax
  \global\let\@address\@empty\global\let\address\relax
  \global\let\@Authors\@empty\global\let\Authors\relax
  \global\let\@date\@empty\global\let\Date\relax
  \global\let\@thanks\@empty\global\let\thanks\relax
  \global\let\@Abstract\@empty\global\let\Abstract\relax
  \global\let\@resume\@empty\global\let\resume\relax
  \global\let\@Keywords\@empty\global\let\Keywords\relax
  \global\let\maketitle\relax\global\let\@maketitle\relax
}
\def\@maketitle{%
\thispagestyle{openin}
  \newpage
  \null
  \begin{center}%
  \let \footnote \thanks
  \vskip 62\p@%
    {\fontsize{15}{17}\fontseries{b}\selectfont \@title \par}%
    \vskip 2\@bls%
%   \ifx\@subtitle\undefined\else{\fontsize{16}{18}\selectfont \@subtitle \par}%
%    \vskip .7\@bls\fi%
    {\normalsize\sc \@author \par}%
    \vskip 13\p@
    {\@address \par}%
        \vskip 10\p@
    \ifx\@date\undefined\else{\normalsize \@date \par}\fi
      \end{center}
%    \vskip 7\p@
%    %    \vskip 23\p@
%    {\unvbox\t@Abstract}%
%    \vskip 3\p@%
%    \ifx\@Keywords\undefined\else  \begin{center}\noindent\begin{minipage}{22pc}{\fontsize{8}{10}\selectfont \@Keywords\par}\end{minipage}\end{center}\fi%
%
%  \par
  \vskip .8\@bls \@plus2\p@ \@minus5\p@
}
%%
\def\and{{\rm and }}
\def\title#1{\def\@title{#1}}
\def\subtitle#1{\def\@subtitle{#1}}
\def\author#1{\def\@author{{\sc #1}}}
\def\address#1{\def\@address{{\fontsize{7.5}{9.5}\it\selectfont #1\par}}}
\def\date#1{\def\@date{\fontsize{7.5}{9.5}\it\selectfont #1\par}}
\def\Keywords#1{\def\@Keywords{{\it Keywords}:~#1}}
\def\Abstract{\@ifnextchar[{\@Abstract}{\@Abstract[]}}
\def\resume{\@ifnextchar[{\@resume}{\@resume[]}}

\def\@Abstract[#1]{%
  \global\setbox\t@Abstract=\vbox\bgroup
   \hsize\textwidth
   \fontsize{10}{10}\selectfont
   \begin{center}
  \noindent\begin{minipage}{22pc}
  \noindent\ignorespaces}
 \def\endabstract{\par\end{minipage}\end{center}\egroup}

\def\@resume[#1]{%
  \global\setbox\t@resume=\vbox\bgroup
   \hsize\textwidth
   \fontsize{9}{10}\selectfont
  \parindent 0em
  \noindent {\bfseries\resumename}\newline
  \noindent\ignorespaces}
 \def\endresume{\par\egroup}

%\newenvironment{Abstract}{
%\bgroup
%\leftmargin=1.8pc
%\rightmargin=1.8pc
%\par}
%{\par\egroup}

\def\abstract{\par\begin{list}{}{\fontsize{9}{10}\selectfont%
      \setlength{\topsep}{0pt}
      \setlength\labelwidth{0pt}%
      \setlength\labelsep{0pt}%
      \setlength\leftmargin{1.8pc}%
      \setlength\rightmargin{1.8pc}%
      \listparindent\parindent}%
\item[]}
\def\endabstract{\end{list}}

\def\keywords{\par\begin{list}{}{\fontsize{8}{10}\selectfont%
      \setlength{\topsep}{6pt}
      \setlength\labelwidth{0pt}%
      \setlength\labelsep{0pt}%
      \setlength\leftmargin{1.8pc}%
      \setlength\rightmargin{1.8pc}%
      \listparindent\parindent}%
\item[]{\it Keywords:}~}
\def\endkeywords{\end{list}}


% Section macros

% Subchapter

\newcommand\subchapter[2]{%
    \goodbreak
    \bgroup
    \parindent\z@
    \vspace{3\baselineskip}%
    \nobreak\rule{21pc}{3pt}%
    \vspace{6\p@}%
    \par\nobreak{\bfseries\raggedright\MakeUppercase{#1}\par}
    \nobreak%
    {\itshape #2}
    \vspace{-1pt}
    \par\nobreak\rule{21pc}{1pt}%
    \vspace{1\p@}
    \egroup
  \@afterindentfalse
  \@afterheading}


% Lowest level heading that takes a number by default
\setcounter{secnumdepth}{2}

\renewcommand{\@seccntformat}[1]{{\csname the#1\endcsname\hspace{.6em}}}

\newcommand*\section{%
  \@startsection{section}{1}{\z@}
  {-28\p@ plus -3\p@ minus -6\p@}{10\p@}
  {\reset@font\raggedright\bfseries\MakeUppercase}}

\newcommand*\subsection{%
  \@startsection{subsection}{2}{\z@}
  {-12\p@ plus -2\p@ minus -6\p@}{1\p@}
  {\reset@font\bfseries\raggedright}}

\newcommand*\subsubsection{%
  \@startsection{subsubsection}{3}{\z@}
  {-12\p@ plus -1\p@ minus -6\p@}{1\p@}
  {\reset@font\bfseries\raggedright}}

\newcommand*\paragraph{%
  \@startsection{paragraph}{4}{\z@}
  {-12\p@ plus -1\p@ minus -6\p@}{-1em}
  {\reset@font\bfseries\raggedright}}

% ********************
% Figures and tables *
% ********************

% Table and array parameters
\setlength\arraycolsep{.5em}
\setlength\tabcolsep{.5em}
\setlength\arrayrulewidth{.5pt}
\setlength\doublerulesep{2.5pt}
\setlength\extrarowheight{\z@}
\renewcommand\arraystretch{1}

% \@caption redefined so entries in Table of figs and tables
% appear as Table 1.1 [Caption] etc, rather than 1.1 [Caption]
\long\def\@caption#1[#2]#3{\par\addcontentsline{\csname ext@#1\endcsname}{#1}
        {\protect\numberline{\csname fnum@#1\endcsname}
        {\ignorespaces #2}}
        \begingroup
        \@parboxrestore
        \normalfont
        \@makecaption{\csname fnum@#1\endcsname}{#3}\par
        \endgroup}

\newlength{\abovecaptionskip}
\newlength{\belowcaptionskip}
\setlength{\abovecaptionskip}{7pt}
\setlength{\belowcaptionskip}{5pt}

\long\def\@makecaption#1#2{\vspace{3\p@}%
  \normalfont\fontsize{8}{9}\selectfont
  {#1}\newline#2}

%\long\def\@tablecaption#1#2{\fontsize{9}{12}\selectfont
%\centering
%  {{#1}\hspace{.5em}#2\strut\par}
%  \vskip.8pt}

\long\def\@tablecaption#1#2{\vspace{5\p@}%
  \normalfont\fontsize{9}{9}\selectfont
  {#1}\newline#2}

\long\def\@photocaption#1#2{\vspace{1\p@}%
  \normalfont\fontsize{9}{12}\selectfont
  \setbox\@tempboxa\hbox{{{#1}\hspace{0.8em}#2}}
  \ifdim \wd\@tempboxa>\hsize
  \unhbox\@tempboxa\par%
  \else
    \hbox to\hsize{\hfill\box\@tempboxa\hfill}
  \fi}


\def\toprule{\noalign{\ifnum0=`}\fi\hrule \@height 1pt \hrule \@height 4.5pt \@width 0pt \futurelet
   \@tempa\@xhline}
\def\midrule{\noalign{\ifnum0=`}\fi \hrule \@height 3pt \@width 0pt \hrule \@height 0.5pt
    \hrule \@height 4pt \@width 0pt \futurelet \@tempa\@xhline}
\def\botrule{\noalign{\ifnum0=`}\fi \hrule \@height 1.5pt \@width 0pt \hrule \@height 1pt \futurelet
   \@tempa\@xhline}

\def\thefigure{\@arabic\c@figure}
\def\thephoto{\@arabic\c@photo}
\def\fps@photo{tbp}
\def\ftype@photo{1}
\def\ext@photo{lof}
\def\fnum@photo{\photoname~\thephoto}
\def\photo{\@float{photo}}
\let\endphoto\end@float
\@namedef{photo*}{\@dblfloat{photo}}
\@namedef{endphoto*}{\end@dblfloat}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{\figurename~\thefigure}
\def\figure{\let\source\figuresource\@float{figure}}
\let\endfigure\end@float
\@namedef{figure*}{\@dblfloat{figure}}
\@namedef{endfigure*}{\end@dblfloat}
\def\thetable{\@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{TABLE~\thetable}
\def\table{\let\@makecaption\@tablecaption\let\source\tablesource\@float{table}}
\def\endtable{\end@float}
\@namedef{table*}{\let\@makecaption\@tablecaption\@dblfloat{table}}
\@namedef{endtable*}{\end@dblfloat}

\newif\if@rotate \@rotatefalse
\newif\if@rotatecenter \@rotatecenterfalse
\def\rotatecenter{\global\@rotatecentertrue}
\def\rotateendcenter{\global\@rotatecenterfalse}
\def\rotate{\global\@rotatetrue}
\def\endrotate{\global\@rotatefalse}
\newdimen\rotdimen
\def\rotstart#1{\special{ps: gsave currentpoint currentpoint translate
    #1 neg exch neg exch translate}}
\def\rotfinish{\special{ps: currentpoint grestore moveto}}
\def\rotl#1{\rotdimen=\ht#1\advance\rotdimen by \dp#1
    \hbox to \rotdimen{\vbox to\wd#1{\vskip \wd#1
    \rotstart{270 rotate}\box #1\vss}\hss}\rotfinish}
\def\rotr#1{\rotdimen=\ht #1\advance\rotdimen by \dp#1
    \hbox to \rotdimen{\vbox to \wd#1{\vskip \wd#1
    \rotstart{90 rotate}\box #1\vss}\hss}\rotfinish}

\newdimen\tempdime
\newbox\temptbox

\let\tablesize\footnotesize

\newenvironment{processtable}[3]{\setbox\temptbox=\hbox{{\normalsize #2}}%
\tempdime\wd\temptbox\@processtable{#1}{#2}{#3}{\tempdime}}
{\relax}

\newenvironment{@processtable}[4]{%
\if@rotate
\setbox4=\vbox{\vss\hbox to \textheight{%
\begin{minipage}{#4}%
\caption{#1}{\normalsize #2}%
\vskip4\p@\noindent
\parbox{#4}{\quad\footnotesize\raggedright #3\par}%
\end{minipage}}\vss}
\rotl{4}
\else
\hbox to \hsize{\hss\begin{minipage}[t]{#4}%
\caption{#1}{\normalsize #2}
\vskip4\p@\noindent
\parbox{#4}{\footnotesize\raggedright #3\par}
\end{minipage}\hss}\fi}
{\relax}

\newlength\figurewidth
\newlength\figcapwidth
\newlength\captionwidth
\newbox\@discard

\def\processfigure#1#2{%
  \settowidth\figurewidth{#1}
\setbox\@discard=\vbox{#2}
\addtocounter{figure}{-1}%
\setbox\@discard=\hbox{}
  \setlength\figcapwidth{\ifdim\figurewidth>\@captionwidth\figurewidth\else\@captionwidth\fi}
  \if@rotate
     \setbox4=\vbox to \textwidth{\vss\hbox to \textheight{%
     \begin{minipage}[c]{\textheight}
     {#1}{#2}
     \end{minipage}}\vss}
     \rotl{4}
  \else
     \begin{center}
     {#1}\break
     \begin{minipage}{\figcapwidth}
     {#2}
     \end{minipage}
     \end{center}
  \fi}

\newcommand{\tablesource}[2][Source:]{\par\vspace{3pt}\noindent{\it #1\/}\space #2}
\newcommand{\figuresource}[2][Source:]{\par\vspace{3pt}\noindent\footnotesize{\it #1\/}\space #2\par}


% ******************************
% List numbering and lettering *
% ******************************
\def\labelenumi{{\rm\arabic{enumi}.}}
\def\theenumi{\arabic{enumi}}
\def\labelenumii{{\rm(\alph{enumii})}}
\def\theenumii{\alph{enumii}}
\def\p@enumii{\theenumi}
\def\labelenumiii{{\rm\arabic{enumiii}}}
\def\theenumiii{\roman{enumiii}}
\def\p@enumiii{\theenumi(\theenumii)}
\def\labelenumiv{{\rm\arabic{enumiv}}}
\def\theenumiv{\Alph{enumiv}}
\def\p@enumiv{\p@enumiii\theenumiii}
\def\labelitemi{$\bullet$}
\def\labelitemii{$\bullet$}
\def\labelitemiii{$\bullet$}
\def\labelitemiv{$\bullet$}

% Changes to the list parameters for enumerate
\def\enumargs{%
   \topsep       9pt
   \itemsep       6\p@
   \labelsep      0.6em
   \leftmargini   9\p@
   \leftmarginii  \z@
   \leftmarginiii \z@
   \leftmarginiv  \z@
   \listparindent \parindent
   \rightmargin   \z@
   \itemindent    \z@}

\newcount\@listdepth \@listdepth=0

\def\enumerate{%
    \@ifnextchar[{\@numerate}{\@numerate[(3)]}}

\def\@numerate[#1]{%
     \ifnum \@enumdepth >3 \@toodeep\else
     \advance\@enumdepth \@ne
     \edef\@enumctr{enum\romannumeral\the\@enumdepth}
     \list{\csname label\@enumctr\endcsname}{%
       \enumargs
       \setlength{\leftmargin}{\csname leftmargin\romannumeral\the\@listdepth\endcsname}
       \usecounter{\@enumctr}
       \settowidth\labelwidth{#1}
       \addtolength{\leftmargin}{\labelwidth}
       \addtolength{\leftmargin}{\labelsep}
       \def\makelabel##1{\hss\llap{##1}}}%
     \fi
}
\def\endenumerate{\endlist\advance \@listdepth -1}

% Changes to the list parameters for itemize
\def\itemargs{%
   \topsep       9pt
   \itemsep       6\p@
   \labelsep      0.6em
   \leftmargini   14.5\p@
   \leftmarginii  \z@
   \leftmarginiii \z@
   \leftmarginiv  \z@
   \rightmargin   \z@
   \listparindent \parindent
   \itemindent    \z@
}

\def\itemize{%
    \@ifnextchar[{\@itemize}{\@itemize[$\bullet$]}}

\def\@itemize[#1]{%
     \ifnum \@itemdepth >3 \@toodeep\else
     \advance\@itemdepth \@ne
     \edef\@itemctr{item\romannumeral\the\@itemdepth}
     \list{\csname label\@itemctr\endcsname}{%
       \itemargs
       \setlength{\leftmargin}{\csname leftmargin\romannumeral\the\@listdepth\endcsname}
       \settowidth\labelwidth{#1}
       \addtolength{\leftmargin}{\labelwidth}
       \addtolength{\leftmargin}{\labelsep}
       \def\makelabel##1{\hss \llap{##1}}}%
     \fi
}
\def\enditemize{\endlist\advance\@listdepth -1}

\def\descriptionlabel#1{\hspace\labelsep \bf #1~}
\def\description{\list{}{\labelwidth\z@ \leftmargin1pc\itemindent-\leftmargin
\itemsep6pt
         \let\makelabel\descriptionlabel}}
\let\enddescription\endlist


\def\@listI{\leftmargin\leftmargini \topsep\medskipamount}
\let\@listi\@listI
\@listi
\def\@listii{\leftmargin\leftmarginii \topsep\z@}
\def\@listiii{\leftmargin\leftmarginiii \topsep\z@}
\def\@listiv{\leftmargin\leftmarginiv \topsep\z@}
\def\@listv{\leftmargin\leftmarginv \topsep\z@}
\def\@listvi{\leftmargin\leftmarginvi \topsep\z@}

% ***********************
% Quotes and Quotations *
% ***********************
\def\quote{\par\begin{list}{}{\small%  Quotations in small type
      \setlength{\topsep}{\medskipamount}
      \setlength\labelwidth{0pt}%
      \setlength\labelsep{0pt}%
      \setlength\leftmargin{1pc}%
      \setlength\rightmargin{1pc}%
      \listparindent\parindent}%
  \item[]}
\def\endquote{\end{list}}

\def\quotation{\par\begin{list}{}{\small%  Quotations in small type
      \setlength{\topsep}{\medskipamount}
      \setlength\labelwidth{0pt}%
      \setlength\labelsep{0pt}%
      \setlength\leftmargin{2pc}%
      \setlength\rightmargin{2pc}%
      \listparindent\parindent}%
  \item[]}
\def\endquotation{\end{list}}

\skip\@mpfootins = \skip\footins
\fboxsep=6\p@
\fboxrule=1\p@

% *******************
% Table of contents *
% *******************
\newcommand\@pnumwidth{4em}
\newcommand\@tocrmarg{2.55em plus 1fil}
\newcommand\@dotsep{1000}
\setcounter{tocdepth}{2}

\def\numberline#1{\hbox{#1.\enskip}}

\def\tableofcontents{\@mainmatterfalse
        \chapter*{Contents}%
        \chaptermark{Contents}%
        \@starttoc{toc}}

\def\@chaptertocline#1#2#3#4#5{%
  \par\vspace{9pt}%
  \ifnum #1>\c@tocdepth \else
    {\leftskip #2\relax \rightskip \@tocrmarg \parfillskip -\rightskip
     \parindent #2\relax\@afterindenttrue
     \interlinepenalty\@M
     \leavevmode
     \@tempdima #3\relax
     \advance\leftskip \@tempdima \null\nobreak\hskip -\leftskip
     {#4}\nobreak
     \leaders\hbox{$\m@th
        \mkern \@dotsep mu\hbox{.}\mkern \@dotsep
        mu$}\hfill
     \nobreak
     \hb@xt@\@pnumwidth{\hfil\normalfont\normalcolor #5}%
     \par}%
  \fi}

\def\@authortocline#1#2#3#4#5{%
  \vskip 1.5\p@
  \ifnum #1>\c@tocdepth \else
    {\leftskip #2\relax \rightskip \@tocrmarg \parfillskip -\rightskip
     \parindent #2\relax\@afterindenttrue
     \interlinepenalty\@M
     \leavevmode
     \@tempdima #3\relax
     \advance\leftskip \@tempdima \null\nobreak\hskip -\leftskip
     {\itshape #4}\nobreak
     \leaders\hbox{$\m@th
        \mkern \@dotsep mu\hbox{.}\mkern \@dotsep
        mu$}\hfill
     \nobreak
     \hb@xt@\@pnumwidth{\hfil\normalfont\normalcolor #5}%
     \par}%
  \fi}

\newcommand*\l@chapter{\@chaptertocline{1}{0pt}{11pt}}
\newcommand*\l@section{\@authortocline{2}{11pt}{11pt}}
%\newcommand*\l@section[2]{}
\newcommand*\l@subsection[2]{}
\newcommand*\l@subsubsection[2]{}


\def\listoftables{%
    \chapter*{List of Tables}%
    \markboth{List of Tables}{List of Tables}%
    \@starttoc{lot}%
    }

\def\listoffigures{
        \chapter*{List of Figures}
        \markboth{List of Figures}{List of Figures}%
        \@starttoc{lof}}


\def\l@figure{\@dottedtocline{1}{0pt}{28pt}}
\def\l@table{\@dottedtocline{1}{0pt}{27pt}}


% ***********
% Footnotes *
% ***********

\renewcommand{\thanks}[1]{\footnotetext[0]{#1}}

\renewcommand\thefootnote{}

\def\@fnsymbol#1{%
  \ensuremath{%
    \ifcase#1
      \or \star
      \or \dagger
      \or \ddagger
      \or \P
      \or \S
      \or ||
      \or \#
      \or \star\star
      \or \dagger\dagger
      \or \ddagger\ddagger
      \or \P\P
      \or \S\S
      \or ||||
      \or \#\#
      \else\@ctrerr\fi
  }
}

\renewcommand\thefootnote{\@fnsymbol\c@footnote}

\setlength\footnotesep{8\p@}
\renewcommand\footnoterule{%
  \kern-3\p@
  \hrule\@width8pc%.4\columnwidth
  \kern2.6\p@}
\newcommand\@makefntext[1]{%
\fontsize{8}{9}\selectfont
    \parindent 1em%
    \noindent
%    \hb@xt@1.8em{\hss\@makefnmark}#1\par}
\enskip$^{\thefootnote}$#1}


% ***********
% References *
% ***********

\def\thebibliography{%
\section*{\refname}
  \addcontentsline{toc}{section}{\refname}%
  \@thebibliography}
\let\endthebibliography=\endlist
\def\@thebibliography#1{\fontsize{8}{9}\selectfont
  \list{\@biblabel{\arabic{enumiv}}}{\settowidth\labelwidth{\@biblabel{#1}}
  \if@nameyear
    \labelwidth\z@ \labelsep\z@ \leftmargin 8pt%\parindent
    \itemindent- 8pt%\parindent
  \else
    \labelsep 5\p@ \itemindent\z@
    \leftmargin\labelwidth \advance\leftmargin\labelsep
  \fi
    \itemsep3\p@
    \usecounter{enumiv}\let\p@enumiv\@empty
    \def\theenumiv{\arabic{enumiv}}}%
  }
\if@nameyear
  \def\@biblabel#1{}
\else
%  \def\@biblabel#1{\hskip \z@ \@plus 1filll[#1]}
  \def\@biblabel#1{\hskip \z@ \@plus 1filll [#1]}
\fi
\newcount\@tempcntc
\def\@citex[#1]#2{\if@filesw\immediate\write\@auxout{\string\citation{#2}}\fi
 \@tempcnta\z@\@tempcntb\m@ne\def\@citea{}\@cite{\@for\@citeb:=#2\do
  {\@ifundefined
   {b@\@citeb}{\@citeo\@tempcntb\m@ne\@citea\def\@citea{,}{\bfseries ?}\@warning
   {Citation `\@citeb' on page \thepage \space undefined}}%
  {\setbox\z@\hbox{\global\@tempcntc0\csname b@\@citeb\endcsname\relax}%
   \ifnum\@tempcntc=\z@ \@citeo\@tempcntb\m@ne
    \@citea\def\@citea{,}\hbox{\csname b@\@citeb\endcsname}%
   \else
    \advance\@tempcntb\@ne
    \ifnum\@tempcntb=\@tempcntc
    \else\advance\@tempcntb\m@ne\@citeo
    \@tempcnta\@tempcntc\@tempcntb\@tempcntc\fi\fi}}\@citeo}{#1}}
\def\@citeo{\ifnum\@tempcnta>\@tempcntb\else\@citea\def\@citea{,}%
 \ifnum\@tempcnta=\@tempcntb\the\@tempcnta\else
  {\advance\@tempcnta\@ne\ifnum\@tempcnta=\@tempcntb \else \def\@citea{--}\fi
   \advance\@tempcnta\m@ne\the\@tempcnta\@citea\the\@tempcntb}\fi\fi}

\newenvironment{ack}[1][ACKNOWLEDGEMENTS]
    {\renewcommand*\section{%
  \@startsection{section}{1}{\z@}
  {-18\p@ plus -3\p@ minus -6\p@}{9\p@}
  {\reset@font\raggedright\footnotesize\MakeUppercase}}
\section*{#1}\footnotesize}
    {}

% **********
% Appendix *
% **********
\newif\ifappend % Are we in the Appendix?
\def\appendix{\par
        \setcounter{chapter}{0}
        \setcounter{section}{0}
        \setcounter{subsection}{0}
        \appendtrue
\def\@chapapp{App.\ }
\def\thechapter{\Alph{chapter}}}

%Math parameters

\setlength{\jot}{5\p@}
\mathchardef\@m=1500   % adapted value

\def\mathindent{10pt}
\def\frenchspacing{\sfcode`\.\@m \sfcode`\?\@m \sfcode`\!\@m
  \sfcode`\:\@m \sfcode`\;\@m \sfcode`\,\@m}

\vbadness=9999
\tolerance=9999
\doublehyphendemerits 1000000   % corresponds to badness 1000
\finalhyphendemerits  1000000  % corresponds to badness 1000

\def\hrulefill{\leavevmode\leaders\hrule height .5pt\hfill\kern\z@}

%%Redefining Eqnarray environment

\def\eqnarray{\stepcounter{equation}\let\@currentlabel=\theequation
\global\@eqnswtrue
\global\@eqcnt\z@\tabskip\mathindent\let\\=\@eqncr
\abovedisplayskip\topsep\ifvmode\advance\abovedisplayskip\partopsep\fi
\belowdisplayskip\abovedisplayskip
\belowdisplayshortskip\abovedisplayskip
\abovedisplayshortskip\abovedisplayskip
$$\halign to
\displaywidth\bgroup\@eqnsel\hskip\@centering$\displaystyle\tabskip\z@
 {##{}}$&\global\@eqcnt\@ne $\displaystyle{{}##{}}$\hfil
 &\global\@eqcnt\tw@ $\displaystyle{{}##}$\hfil
 \tabskip\@centering&\llap{##}\tabskip\z@\cr}
\def\endeqnarray{\@@eqncr\egroup
 \global\advance\c@equation\m@ne$$\global\@ignoretrue }

\flushbottom
\frenchspacing
\pagestyle{headings}

\DeclareFontFamily{U}{mtt}{}
\DeclareFontShape{U}{mtt}{m}{up}{<->mtgu}{}
\DeclareSymbolFont{upgreek}{U}{mtt}{m}{up}

\DeclareMathSymbol{\rmu}{\mathalpha}{upgreek}{'155}

\theorembodyfont{\itshape}
\theoremheaderfont{\normalfont\itshape}
\setlength{\theorempreskipamount}{6pt plus 2pt}
\setlength{\theorempostskipamount}{6pt plus 2pt}

\begingroup \makeatletter
\gdef\th@plain{\normalfont\itshape\setlength  \labelsep  {.5em}
  \def\@begintheorem##1##2{%
        \item[\hskip\labelsep \theorem@headerfont ##1\ {##2.}]}%
\def\@opargbegintheorem##1##2##3{%
   \item[\hskip\labelsep \theorem@headerfont ##1\ ##2\ {\rm (##3).}]}}
\endgroup

\def\tra#1{\spaceskip 0.#1em plus 0.15em minus 0.09em\relax}%

\def\proc#1{\medbreak\noindent{\it #1}\hspace{1ex}\ignorespaces}
\def\ep{\noindent{\hfill $\Box$}}

\endinput
